@@ -3,9 +3,9 @@ Main interface for dms service type definitions.
 
 Usage::
 
-    from mypy_boto3.dms.type_defs import PendingMaintenanceActionTypeDef
+    from mypy_boto3.dms.type_defs import AccountQuotaTypeDef
 
-    data: PendingMaintenanceActionTypeDef = {...}
+    data: AccountQuotaTypeDef = {...}
 """
 from datetime import datetime
 import sys
@@ -22,71 +22,71 @@ else:
 
 
 __all__ = (
-    "PendingMaintenanceActionTypeDef",
-    "ResourcePendingMaintenanceActionsTypeDef",
-    "ApplyPendingMaintenanceActionResponseTypeDef",
+    "AccountQuotaTypeDef",
+    "AvailabilityZoneTypeDef",
+    "CertificateTypeDef",
+    "ConnectionTypeDef",
     "DmsTransferSettingsTypeDef",
     "DynamoDbSettingsTypeDef",
     "ElasticsearchSettingsTypeDef",
+    "EndpointTypeDef",
+    "EventCategoryGroupTypeDef",
+    "EventSubscriptionTypeDef",
+    "EventTypeDef",
     "KafkaSettingsTypeDef",
     "KinesisSettingsTypeDef",
     "MongoDbSettingsTypeDef",
     "NeptuneSettingsTypeDef",
+    "OrderableReplicationInstanceTypeDef",
+    "PendingMaintenanceActionTypeDef",
     "RedshiftSettingsTypeDef",
-    "S3SettingsTypeDef",
-    "EndpointTypeDef",
-    "CreateEndpointResponseTypeDef",
-    "EventSubscriptionTypeDef",
-    "CreateEventSubscriptionResponseTypeDef",
-    "ReplicationPendingModifiedValuesTypeDef",
-    "AvailabilityZoneTypeDef",
-    "SubnetTypeDef",
-    "ReplicationSubnetGroupTypeDef",
-    "VpcSecurityGroupMembershipTypeDef",
+    "RefreshSchemasStatusTypeDef",
+    "ReplicationInstanceTaskLogTypeDef",
     "ReplicationInstanceTypeDef",
-    "CreateReplicationInstanceResponseTypeDef",
-    "CreateReplicationSubnetGroupResponseTypeDef",
+    "ReplicationPendingModifiedValuesTypeDef",
+    "ReplicationSubnetGroupTypeDef",
+    "ReplicationTaskAssessmentResultTypeDef",
     "ReplicationTaskStatsTypeDef",
     "ReplicationTaskTypeDef",
+    "ResourcePendingMaintenanceActionsTypeDef",
+    "S3SettingsTypeDef",
+    "SubnetTypeDef",
+    "SupportedEndpointTypeTypeDef",
+    "TableStatisticsTypeDef",
+    "TagTypeDef",
+    "VpcSecurityGroupMembershipTypeDef",
+    "ApplyPendingMaintenanceActionResponseTypeDef",
+    "CreateEndpointResponseTypeDef",
+    "CreateEventSubscriptionResponseTypeDef",
+    "CreateReplicationInstanceResponseTypeDef",
+    "CreateReplicationSubnetGroupResponseTypeDef",
     "CreateReplicationTaskResponseTypeDef",
-    "CertificateTypeDef",
     "DeleteCertificateResponseTypeDef",
-    "ConnectionTypeDef",
     "DeleteConnectionResponseTypeDef",
     "DeleteEndpointResponseTypeDef",
     "DeleteEventSubscriptionResponseTypeDef",
     "DeleteReplicationInstanceResponseTypeDef",
     "DeleteReplicationTaskResponseTypeDef",
-    "AccountQuotaTypeDef",
     "DescribeAccountAttributesResponseTypeDef",
     "DescribeCertificatesResponseTypeDef",
     "DescribeConnectionsResponseTypeDef",
-    "SupportedEndpointTypeTypeDef",
     "DescribeEndpointTypesResponseTypeDef",
     "DescribeEndpointsResponseTypeDef",
-    "EventCategoryGroupTypeDef",
     "DescribeEventCategoriesResponseTypeDef",
     "DescribeEventSubscriptionsResponseTypeDef",
-    "EventTypeDef",
     "DescribeEventsResponseTypeDef",
-    "OrderableReplicationInstanceTypeDef",
     "DescribeOrderableReplicationInstancesResponseTypeDef",
     "DescribePendingMaintenanceActionsResponseTypeDef",
-    "RefreshSchemasStatusTypeDef",
     "DescribeRefreshSchemasStatusResponseTypeDef",
-    "ReplicationInstanceTaskLogTypeDef",
     "DescribeReplicationInstanceTaskLogsResponseTypeDef",
     "DescribeReplicationInstancesResponseTypeDef",
     "DescribeReplicationSubnetGroupsResponseTypeDef",
-    "ReplicationTaskAssessmentResultTypeDef",
     "DescribeReplicationTaskAssessmentResultsResponseTypeDef",
     "DescribeReplicationTasksResponseTypeDef",
     "DescribeSchemasResponseTypeDef",
-    "TableStatisticsTypeDef",
     "DescribeTableStatisticsResponseTypeDef",
     "FilterTypeDef",
     "ImportCertificateResponseTypeDef",
-    "TagTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "ModifyEndpointResponseTypeDef",
     "ModifyEventSubscriptionResponseTypeDef",
@@ -105,34 +105,42 @@ __all__ = (
     "WaiterConfigTypeDef",
 )
 
-PendingMaintenanceActionTypeDef = TypedDict(
-    "PendingMaintenanceActionTypeDef",
+AccountQuotaTypeDef = TypedDict(
+    "AccountQuotaTypeDef", {"AccountQuotaName": str, "Used": int, "Max": int}, total=False
+)
+
+AvailabilityZoneTypeDef = TypedDict("AvailabilityZoneTypeDef", {"Name": str}, total=False)
+
+CertificateTypeDef = TypedDict(
+    "CertificateTypeDef",
     {
-        "Action": str,
-        "AutoAppliedAfterDate": datetime,
-        "ForcedApplyDate": datetime,
-        "OptInStatus": str,
-        "CurrentApplyDate": datetime,
-        "Description": str,
+        "CertificateIdentifier": str,
+        "CertificateCreationDate": datetime,
+        "CertificatePem": str,
+        "CertificateWallet": Union[bytes, IO],
+        "CertificateArn": str,
+        "CertificateOwner": str,
+        "ValidFromDate": datetime,
+        "ValidToDate": datetime,
+        "SigningAlgorithm": str,
+        "KeyLength": int,
     },
     total=False,
 )
 
-ResourcePendingMaintenanceActionsTypeDef = TypedDict(
-    "ResourcePendingMaintenanceActionsTypeDef",
+ConnectionTypeDef = TypedDict(
+    "ConnectionTypeDef",
     {
-        "ResourceIdentifier": str,
-        "PendingMaintenanceActionDetails": List[PendingMaintenanceActionTypeDef],
+        "ReplicationInstanceArn": str,
+        "EndpointArn": str,
+        "Status": str,
+        "LastFailureMessage": str,
+        "EndpointIdentifier": str,
+        "ReplicationInstanceIdentifier": str,
     },
     total=False,
 )
 
-ApplyPendingMaintenanceActionResponseTypeDef = TypedDict(
-    "ApplyPendingMaintenanceActionResponseTypeDef",
-    {"ResourcePendingMaintenanceActions": ResourcePendingMaintenanceActionsTypeDef},
-    total=False,
-)
-
 DmsTransferSettingsTypeDef = TypedDict(
     "DmsTransferSettingsTypeDef", {"ServiceAccessRoleArn": str, "BucketName": str}, total=False
 )
@@ -155,6 +163,71 @@ class ElasticsearchSettingsTypeDef(
     pass
 
 
+EndpointTypeDef = TypedDict(
+    "EndpointTypeDef",
+    {
+        "EndpointIdentifier": str,
+        "EndpointType": Literal["source", "target"],
+        "EngineName": str,
+        "EngineDisplayName": str,
+        "Username": str,
+        "ServerName": str,
+        "Port": int,
+        "DatabaseName": str,
+        "ExtraConnectionAttributes": str,
+        "Status": str,
+        "KmsKeyId": str,
+        "EndpointArn": str,
+        "CertificateArn": str,
+        "SslMode": Literal["none", "require", "verify-ca", "verify-full"],
+        "ServiceAccessRoleArn": str,
+        "ExternalTableDefinition": str,
+        "ExternalId": str,
+        "DynamoDbSettings": "DynamoDbSettingsTypeDef",
+        "S3Settings": "S3SettingsTypeDef",
+        "DmsTransferSettings": "DmsTransferSettingsTypeDef",
+        "MongoDbSettings": "MongoDbSettingsTypeDef",
+        "KinesisSettings": "KinesisSettingsTypeDef",
+        "KafkaSettings": "KafkaSettingsTypeDef",
+        "ElasticsearchSettings": "ElasticsearchSettingsTypeDef",
+        "NeptuneSettings": "NeptuneSettingsTypeDef",
+        "RedshiftSettings": "RedshiftSettingsTypeDef",
+    },
+    total=False,
+)
+
+EventCategoryGroupTypeDef = TypedDict(
+    "EventCategoryGroupTypeDef", {"SourceType": str, "EventCategories": List[str]}, total=False
+)
+
+EventSubscriptionTypeDef = TypedDict(
+    "EventSubscriptionTypeDef",
+    {
+        "CustomerAwsId": str,
+        "CustSubscriptionId": str,
+        "SnsTopicArn": str,
+        "Status": str,
+        "SubscriptionCreationTime": str,
+        "SourceType": str,
+        "SourceIdsList": List[str],
+        "EventCategoriesList": List[str],
+        "Enabled": bool,
+    },
+    total=False,
+)
+
+EventTypeDef = TypedDict(
+    "EventTypeDef",
+    {
+        "SourceIdentifier": str,
+        "SourceType": Literal["replication-instance"],
+        "Message": str,
+        "EventCategories": List[str],
+        "Date": datetime,
+    },
+    total=False,
+)
+
 KafkaSettingsTypeDef = TypedDict("KafkaSettingsTypeDef", {"Broker": str, "Topic": str}, total=False)
 
 KinesisSettingsTypeDef = TypedDict(
@@ -211,6 +284,35 @@ class NeptuneSettingsTypeDef(_RequiredNeptuneSettingsTypeDef, _OptionalNeptuneSe
     pass
 
 
+OrderableReplicationInstanceTypeDef = TypedDict(
+    "OrderableReplicationInstanceTypeDef",
+    {
+        "EngineVersion": str,
+        "ReplicationInstanceClass": str,
+        "StorageType": str,
+        "MinAllocatedStorage": int,
+        "MaxAllocatedStorage": int,
+        "DefaultAllocatedStorage": int,
+        "IncludedAllocatedStorage": int,
+        "AvailabilityZones": List[str],
+        "ReleaseStatus": Literal["beta"],
+    },
+    total=False,
+)
+
+PendingMaintenanceActionTypeDef = TypedDict(
+    "PendingMaintenanceActionTypeDef",
+    {
+        "Action": str,
+        "AutoAppliedAfterDate": datetime,
+        "ForcedApplyDate": datetime,
+        "OptInStatus": str,
+        "CurrentApplyDate": datetime,
+        "Description": str,
+    },
+    total=False,
+)
+
 RedshiftSettingsTypeDef = TypedDict(
     "RedshiftSettingsTypeDef",
     {
@@ -243,132 +345,24 @@ RedshiftSettingsTypeDef = TypedDict(
     total=False,
 )
 
-S3SettingsTypeDef = TypedDict(
-    "S3SettingsTypeDef",
+RefreshSchemasStatusTypeDef = TypedDict(
+    "RefreshSchemasStatusTypeDef",
     {
-        "ServiceAccessRoleArn": str,
-        "ExternalTableDefinition": str,
-        "CsvRowDelimiter": str,
-        "CsvDelimiter": str,
-        "BucketFolder": str,
-        "BucketName": str,
-        "CompressionType": Literal["none", "gzip"],
-        "EncryptionMode": Literal["sse-s3", "sse-kms"],
-        "ServerSideEncryptionKmsKeyId": str,
-        "DataFormat": Literal["csv", "parquet"],
-        "EncodingType": Literal["plain", "plain-dictionary", "rle-dictionary"],
-        "DictPageSizeLimit": int,
-        "RowGroupLength": int,
-        "DataPageSize": int,
-        "ParquetVersion": Literal["parquet-1-0", "parquet-2-0"],
-        "EnableStatistics": bool,
-        "IncludeOpForFullLoad": bool,
-        "CdcInsertsOnly": bool,
-        "TimestampColumnName": str,
-        "ParquetTimestampInMillisecond": bool,
-        "CdcInsertsAndUpdates": bool,
-    },
-    total=False,
-)
-
-EndpointTypeDef = TypedDict(
-    "EndpointTypeDef",
-    {
-        "EndpointIdentifier": str,
-        "EndpointType": Literal["source", "target"],
-        "EngineName": str,
-        "EngineDisplayName": str,
-        "Username": str,
-        "ServerName": str,
-        "Port": int,
-        "DatabaseName": str,
-        "ExtraConnectionAttributes": str,
-        "Status": str,
-        "KmsKeyId": str,
         "EndpointArn": str,
-        "CertificateArn": str,
-        "SslMode": Literal["none", "require", "verify-ca", "verify-full"],
-        "ServiceAccessRoleArn": str,
-        "ExternalTableDefinition": str,
-        "ExternalId": str,
-        "DynamoDbSettings": DynamoDbSettingsTypeDef,
-        "S3Settings": S3SettingsTypeDef,
-        "DmsTransferSettings": DmsTransferSettingsTypeDef,
-        "MongoDbSettings": MongoDbSettingsTypeDef,
-        "KinesisSettings": KinesisSettingsTypeDef,
-        "KafkaSettings": KafkaSettingsTypeDef,
-        "ElasticsearchSettings": ElasticsearchSettingsTypeDef,
-        "NeptuneSettings": NeptuneSettingsTypeDef,
-        "RedshiftSettings": RedshiftSettingsTypeDef,
+        "ReplicationInstanceArn": str,
+        "Status": Literal["successful", "failed", "refreshing"],
+        "LastRefreshDate": datetime,
+        "LastFailureMessage": str,
     },
     total=False,
 )
 
-CreateEndpointResponseTypeDef = TypedDict(
-    "CreateEndpointResponseTypeDef", {"Endpoint": EndpointTypeDef}, total=False
-)
-
-EventSubscriptionTypeDef = TypedDict(
-    "EventSubscriptionTypeDef",
-    {
-        "CustomerAwsId": str,
-        "CustSubscriptionId": str,
-        "SnsTopicArn": str,
-        "Status": str,
-        "SubscriptionCreationTime": str,
-        "SourceType": str,
-        "SourceIdsList": List[str],
-        "EventCategoriesList": List[str],
-        "Enabled": bool,
-    },
+ReplicationInstanceTaskLogTypeDef = TypedDict(
+    "ReplicationInstanceTaskLogTypeDef",
+    {"ReplicationTaskName": str, "ReplicationTaskArn": str, "ReplicationInstanceTaskLogSize": int},
     total=False,
 )
 
-CreateEventSubscriptionResponseTypeDef = TypedDict(
-    "CreateEventSubscriptionResponseTypeDef",
-    {"EventSubscription": EventSubscriptionTypeDef},
-    total=False,
-)
-
-ReplicationPendingModifiedValuesTypeDef = TypedDict(
-    "ReplicationPendingModifiedValuesTypeDef",
-    {
-        "ReplicationInstanceClass": str,
-        "AllocatedStorage": int,
-        "MultiAZ": bool,
-        "EngineVersion": str,
-    },
-    total=False,
-)
-
-AvailabilityZoneTypeDef = TypedDict("AvailabilityZoneTypeDef", {"Name": str}, total=False)
-
-SubnetTypeDef = TypedDict(
-    "SubnetTypeDef",
-    {
-        "SubnetIdentifier": str,
-        "SubnetAvailabilityZone": AvailabilityZoneTypeDef,
-        "SubnetStatus": str,
-    },
-    total=False,
-)
-
-ReplicationSubnetGroupTypeDef = TypedDict(
-    "ReplicationSubnetGroupTypeDef",
-    {
-        "ReplicationSubnetGroupIdentifier": str,
-        "ReplicationSubnetGroupDescription": str,
-        "VpcId": str,
-        "SubnetGroupStatus": str,
-        "Subnets": List[SubnetTypeDef],
-    },
-    total=False,
-)
-
-VpcSecurityGroupMembershipTypeDef = TypedDict(
-    "VpcSecurityGroupMembershipTypeDef", {"VpcSecurityGroupId": str, "Status": str}, total=False
-)
-
 ReplicationInstanceTypeDef = TypedDict(
     "ReplicationInstanceTypeDef",
     {
@@ -377,11 +371,11 @@ ReplicationInstanceTypeDef = TypedDict(
         "ReplicationInstanceStatus": str,
         "AllocatedStorage": int,
         "InstanceCreateTime": datetime,
-        "VpcSecurityGroups": List[VpcSecurityGroupMembershipTypeDef],
+        "VpcSecurityGroups": List["VpcSecurityGroupMembershipTypeDef"],
         "AvailabilityZone": str,
-        "ReplicationSubnetGroup": ReplicationSubnetGroupTypeDef,
+        "ReplicationSubnetGroup": "ReplicationSubnetGroupTypeDef",
         "PreferredMaintenanceWindow": str,
-        "PendingModifiedValues": ReplicationPendingModifiedValuesTypeDef,
+        "PendingModifiedValues": "ReplicationPendingModifiedValuesTypeDef",
         "MultiAZ": bool,
         "EngineVersion": str,
         "AutoMinorVersionUpgrade": bool,
@@ -399,15 +393,40 @@ ReplicationInstanceTypeDef = TypedDict(
     total=False,
 )
 
-CreateReplicationInstanceResponseTypeDef = TypedDict(
-    "CreateReplicationInstanceResponseTypeDef",
-    {"ReplicationInstance": ReplicationInstanceTypeDef},
+ReplicationPendingModifiedValuesTypeDef = TypedDict(
+    "ReplicationPendingModifiedValuesTypeDef",
+    {
+        "ReplicationInstanceClass": str,
+        "AllocatedStorage": int,
+        "MultiAZ": bool,
+        "EngineVersion": str,
+    },
     total=False,
 )
 
-CreateReplicationSubnetGroupResponseTypeDef = TypedDict(
-    "CreateReplicationSubnetGroupResponseTypeDef",
-    {"ReplicationSubnetGroup": ReplicationSubnetGroupTypeDef},
+ReplicationSubnetGroupTypeDef = TypedDict(
+    "ReplicationSubnetGroupTypeDef",
+    {
+        "ReplicationSubnetGroupIdentifier": str,
+        "ReplicationSubnetGroupDescription": str,
+        "VpcId": str,
+        "SubnetGroupStatus": str,
+        "Subnets": List["SubnetTypeDef"],
+    },
+    total=False,
+)
+
+ReplicationTaskAssessmentResultTypeDef = TypedDict(
+    "ReplicationTaskAssessmentResultTypeDef",
+    {
+        "ReplicationTaskIdentifier": str,
+        "ReplicationTaskArn": str,
+        "ReplicationTaskLastAssessmentDate": datetime,
+        "AssessmentStatus": str,
+        "AssessmentResultsFile": str,
+        "AssessmentResults": str,
+        "S3ObjectUrl": str,
+    },
     total=False,
 )
 
@@ -448,93 +467,56 @@ ReplicationTaskTypeDef = TypedDict(
         "CdcStopPosition": str,
         "RecoveryCheckpoint": str,
         "ReplicationTaskArn": str,
-        "ReplicationTaskStats": ReplicationTaskStatsTypeDef,
+        "ReplicationTaskStats": "ReplicationTaskStatsTypeDef",
         "TaskData": str,
     },
     total=False,
 )
 
-CreateReplicationTaskResponseTypeDef = TypedDict(
-    "CreateReplicationTaskResponseTypeDef", {"ReplicationTask": ReplicationTaskTypeDef}, total=False
-)
-
-CertificateTypeDef = TypedDict(
-    "CertificateTypeDef",
+ResourcePendingMaintenanceActionsTypeDef = TypedDict(
+    "ResourcePendingMaintenanceActionsTypeDef",
     {
-        "CertificateIdentifier": str,
-        "CertificateCreationDate": datetime,
-        "CertificatePem": str,
-        "CertificateWallet": Union[bytes, IO],
-        "CertificateArn": str,
-        "CertificateOwner": str,
-        "ValidFromDate": datetime,
-        "ValidToDate": datetime,
-        "SigningAlgorithm": str,
-        "KeyLength": int,
+        "ResourceIdentifier": str,
+        "PendingMaintenanceActionDetails": List["PendingMaintenanceActionTypeDef"],
     },
     total=False,
 )
 
-DeleteCertificateResponseTypeDef = TypedDict(
-    "DeleteCertificateResponseTypeDef", {"Certificate": CertificateTypeDef}, total=False
-)
-
-ConnectionTypeDef = TypedDict(
-    "ConnectionTypeDef",
+S3SettingsTypeDef = TypedDict(
+    "S3SettingsTypeDef",
     {
-        "ReplicationInstanceArn": str,
-        "EndpointArn": str,
-        "Status": str,
-        "LastFailureMessage": str,
-        "EndpointIdentifier": str,
-        "ReplicationInstanceIdentifier": str,
+        "ServiceAccessRoleArn": str,
+        "ExternalTableDefinition": str,
+        "CsvRowDelimiter": str,
+        "CsvDelimiter": str,
+        "BucketFolder": str,
+        "BucketName": str,
+        "CompressionType": Literal["none", "gzip"],
+        "EncryptionMode": Literal["sse-s3", "sse-kms"],
+        "ServerSideEncryptionKmsKeyId": str,
+        "DataFormat": Literal["csv", "parquet"],
+        "EncodingType": Literal["plain", "plain-dictionary", "rle-dictionary"],
+        "DictPageSizeLimit": int,
+        "RowGroupLength": int,
+        "DataPageSize": int,
+        "ParquetVersion": Literal["parquet-1-0", "parquet-2-0"],
+        "EnableStatistics": bool,
+        "IncludeOpForFullLoad": bool,
+        "CdcInsertsOnly": bool,
+        "TimestampColumnName": str,
+        "ParquetTimestampInMillisecond": bool,
+        "CdcInsertsAndUpdates": bool,
     },
     total=False,
 )
 
-DeleteConnectionResponseTypeDef = TypedDict(
-    "DeleteConnectionResponseTypeDef", {"Connection": ConnectionTypeDef}, total=False
-)
-
-DeleteEndpointResponseTypeDef = TypedDict(
-    "DeleteEndpointResponseTypeDef", {"Endpoint": EndpointTypeDef}, total=False
-)
-
-DeleteEventSubscriptionResponseTypeDef = TypedDict(
-    "DeleteEventSubscriptionResponseTypeDef",
-    {"EventSubscription": EventSubscriptionTypeDef},
-    total=False,
-)
-
-DeleteReplicationInstanceResponseTypeDef = TypedDict(
-    "DeleteReplicationInstanceResponseTypeDef",
-    {"ReplicationInstance": ReplicationInstanceTypeDef},
-    total=False,
-)
-
-DeleteReplicationTaskResponseTypeDef = TypedDict(
-    "DeleteReplicationTaskResponseTypeDef", {"ReplicationTask": ReplicationTaskTypeDef}, total=False
-)
-
-AccountQuotaTypeDef = TypedDict(
-    "AccountQuotaTypeDef", {"AccountQuotaName": str, "Used": int, "Max": int}, total=False
-)
-
-DescribeAccountAttributesResponseTypeDef = TypedDict(
-    "DescribeAccountAttributesResponseTypeDef",
-    {"AccountQuotas": List[AccountQuotaTypeDef], "UniqueAccountIdentifier": str},
-    total=False,
-)
-
-DescribeCertificatesResponseTypeDef = TypedDict(
-    "DescribeCertificatesResponseTypeDef",
-    {"Marker": str, "Certificates": List[CertificateTypeDef]},
-    total=False,
-)
-
-DescribeConnectionsResponseTypeDef = TypedDict(
-    "DescribeConnectionsResponseTypeDef",
-    {"Marker": str, "Connections": List[ConnectionTypeDef]},
+SubnetTypeDef = TypedDict(
+    "SubnetTypeDef",
+    {
+        "SubnetIdentifier": str,
+        "SubnetAvailabilityZone": "AvailabilityZoneTypeDef",
+        "SubnetStatus": str,
+    },
     total=False,
 )
 
@@ -550,158 +532,6 @@ SupportedEndpointTypeTypeDef = TypedDict(
     total=False,
 )
 
-DescribeEndpointTypesResponseTypeDef = TypedDict(
-    "DescribeEndpointTypesResponseTypeDef",
-    {"Marker": str, "SupportedEndpointTypes": List[SupportedEndpointTypeTypeDef]},
-    total=False,
-)
-
-DescribeEndpointsResponseTypeDef = TypedDict(
-    "DescribeEndpointsResponseTypeDef",
-    {"Marker": str, "Endpoints": List[EndpointTypeDef]},
-    total=False,
-)
-
-EventCategoryGroupTypeDef = TypedDict(
-    "EventCategoryGroupTypeDef", {"SourceType": str, "EventCategories": List[str]}, total=False
-)
-
-DescribeEventCategoriesResponseTypeDef = TypedDict(
-    "DescribeEventCategoriesResponseTypeDef",
-    {"EventCategoryGroupList": List[EventCategoryGroupTypeDef]},
-    total=False,
-)
-
-DescribeEventSubscriptionsResponseTypeDef = TypedDict(
-    "DescribeEventSubscriptionsResponseTypeDef",
-    {"Marker": str, "EventSubscriptionsList": List[EventSubscriptionTypeDef]},
-    total=False,
-)
-
-EventTypeDef = TypedDict(
-    "EventTypeDef",
-    {
-        "SourceIdentifier": str,
-        "SourceType": Literal["replication-instance"],
-        "Message": str,
-        "EventCategories": List[str],
-        "Date": datetime,
-    },
-    total=False,
-)
-
-DescribeEventsResponseTypeDef = TypedDict(
-    "DescribeEventsResponseTypeDef", {"Marker": str, "Events": List[EventTypeDef]}, total=False
-)
-
-OrderableReplicationInstanceTypeDef = TypedDict(
-    "OrderableReplicationInstanceTypeDef",
-    {
-        "EngineVersion": str,
-        "ReplicationInstanceClass": str,
-        "StorageType": str,
-        "MinAllocatedStorage": int,
-        "MaxAllocatedStorage": int,
-        "DefaultAllocatedStorage": int,
-        "IncludedAllocatedStorage": int,
-        "AvailabilityZones": List[str],
-        "ReleaseStatus": Literal["beta"],
-    },
-    total=False,
-)
-
-DescribeOrderableReplicationInstancesResponseTypeDef = TypedDict(
-    "DescribeOrderableReplicationInstancesResponseTypeDef",
-    {"OrderableReplicationInstances": List[OrderableReplicationInstanceTypeDef], "Marker": str},
-    total=False,
-)
-
-DescribePendingMaintenanceActionsResponseTypeDef = TypedDict(
-    "DescribePendingMaintenanceActionsResponseTypeDef",
-    {"PendingMaintenanceActions": List[ResourcePendingMaintenanceActionsTypeDef], "Marker": str},
-    total=False,
-)
-
-RefreshSchemasStatusTypeDef = TypedDict(
-    "RefreshSchemasStatusTypeDef",
-    {
-        "EndpointArn": str,
-        "ReplicationInstanceArn": str,
-        "Status": Literal["successful", "failed", "refreshing"],
-        "LastRefreshDate": datetime,
-        "LastFailureMessage": str,
-    },
-    total=False,
-)
-
-DescribeRefreshSchemasStatusResponseTypeDef = TypedDict(
-    "DescribeRefreshSchemasStatusResponseTypeDef",
-    {"RefreshSchemasStatus": RefreshSchemasStatusTypeDef},
-    total=False,
-)
-
-ReplicationInstanceTaskLogTypeDef = TypedDict(
-    "ReplicationInstanceTaskLogTypeDef",
-    {"ReplicationTaskName": str, "ReplicationTaskArn": str, "ReplicationInstanceTaskLogSize": int},
-    total=False,
-)
-
-DescribeReplicationInstanceTaskLogsResponseTypeDef = TypedDict(
-    "DescribeReplicationInstanceTaskLogsResponseTypeDef",
-    {
-        "ReplicationInstanceArn": str,
-        "ReplicationInstanceTaskLogs": List[ReplicationInstanceTaskLogTypeDef],
-        "Marker": str,
-    },
-    total=False,
-)
-
-DescribeReplicationInstancesResponseTypeDef = TypedDict(
-    "DescribeReplicationInstancesResponseTypeDef",
-    {"Marker": str, "ReplicationInstances": List[ReplicationInstanceTypeDef]},
-    total=False,
-)
-
-DescribeReplicationSubnetGroupsResponseTypeDef = TypedDict(
-    "DescribeReplicationSubnetGroupsResponseTypeDef",
-    {"Marker": str, "ReplicationSubnetGroups": List[ReplicationSubnetGroupTypeDef]},
-    total=False,
-)
-
-ReplicationTaskAssessmentResultTypeDef = TypedDict(
-    "ReplicationTaskAssessmentResultTypeDef",
-    {
-        "ReplicationTaskIdentifier": str,
-        "ReplicationTaskArn": str,
-        "ReplicationTaskLastAssessmentDate": datetime,
-        "AssessmentStatus": str,
-        "AssessmentResultsFile": str,
-        "AssessmentResults": str,
-        "S3ObjectUrl": str,
-    },
-    total=False,
-)
-
-DescribeReplicationTaskAssessmentResultsResponseTypeDef = TypedDict(
-    "DescribeReplicationTaskAssessmentResultsResponseTypeDef",
-    {
-        "Marker": str,
-        "BucketName": str,
-        "ReplicationTaskAssessmentResults": List[ReplicationTaskAssessmentResultTypeDef],
-    },
-    total=False,
-)
-
-DescribeReplicationTasksResponseTypeDef = TypedDict(
-    "DescribeReplicationTasksResponseTypeDef",
-    {"Marker": str, "ReplicationTasks": List[ReplicationTaskTypeDef]},
-    total=False,
-)
-
-DescribeSchemasResponseTypeDef = TypedDict(
-    "DescribeSchemasResponseTypeDef", {"Marker": str, "Schemas": List[str]}, total=False
-)
-
 TableStatisticsTypeDef = TypedDict(
     "TableStatisticsTypeDef",
     {
@@ -728,48 +558,224 @@ TableStatisticsTypeDef = TypedDict(
     total=False,
 )
 
+TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str}, total=False)
+
+VpcSecurityGroupMembershipTypeDef = TypedDict(
+    "VpcSecurityGroupMembershipTypeDef", {"VpcSecurityGroupId": str, "Status": str}, total=False
+)
+
+ApplyPendingMaintenanceActionResponseTypeDef = TypedDict(
+    "ApplyPendingMaintenanceActionResponseTypeDef",
+    {"ResourcePendingMaintenanceActions": "ResourcePendingMaintenanceActionsTypeDef"},
+    total=False,
+)
+
+CreateEndpointResponseTypeDef = TypedDict(
+    "CreateEndpointResponseTypeDef", {"Endpoint": "EndpointTypeDef"}, total=False
+)
+
+CreateEventSubscriptionResponseTypeDef = TypedDict(
+    "CreateEventSubscriptionResponseTypeDef",
+    {"EventSubscription": "EventSubscriptionTypeDef"},
+    total=False,
+)
+
+CreateReplicationInstanceResponseTypeDef = TypedDict(
+    "CreateReplicationInstanceResponseTypeDef",
+    {"ReplicationInstance": "ReplicationInstanceTypeDef"},
+    total=False,
+)
+
+CreateReplicationSubnetGroupResponseTypeDef = TypedDict(
+    "CreateReplicationSubnetGroupResponseTypeDef",
+    {"ReplicationSubnetGroup": "ReplicationSubnetGroupTypeDef"},
+    total=False,
+)
+
+CreateReplicationTaskResponseTypeDef = TypedDict(
+    "CreateReplicationTaskResponseTypeDef",
+    {"ReplicationTask": "ReplicationTaskTypeDef"},
+    total=False,
+)
+
+DeleteCertificateResponseTypeDef = TypedDict(
+    "DeleteCertificateResponseTypeDef", {"Certificate": "CertificateTypeDef"}, total=False
+)
+
+DeleteConnectionResponseTypeDef = TypedDict(
+    "DeleteConnectionResponseTypeDef", {"Connection": "ConnectionTypeDef"}, total=False
+)
+
+DeleteEndpointResponseTypeDef = TypedDict(
+    "DeleteEndpointResponseTypeDef", {"Endpoint": "EndpointTypeDef"}, total=False
+)
+
+DeleteEventSubscriptionResponseTypeDef = TypedDict(
+    "DeleteEventSubscriptionResponseTypeDef",
+    {"EventSubscription": "EventSubscriptionTypeDef"},
+    total=False,
+)
+
+DeleteReplicationInstanceResponseTypeDef = TypedDict(
+    "DeleteReplicationInstanceResponseTypeDef",
+    {"ReplicationInstance": "ReplicationInstanceTypeDef"},
+    total=False,
+)
+
+DeleteReplicationTaskResponseTypeDef = TypedDict(
+    "DeleteReplicationTaskResponseTypeDef",
+    {"ReplicationTask": "ReplicationTaskTypeDef"},
+    total=False,
+)
+
+DescribeAccountAttributesResponseTypeDef = TypedDict(
+    "DescribeAccountAttributesResponseTypeDef",
+    {"AccountQuotas": List["AccountQuotaTypeDef"], "UniqueAccountIdentifier": str},
+    total=False,
+)
+
+DescribeCertificatesResponseTypeDef = TypedDict(
+    "DescribeCertificatesResponseTypeDef",
+    {"Marker": str, "Certificates": List["CertificateTypeDef"]},
+    total=False,
+)
+
+DescribeConnectionsResponseTypeDef = TypedDict(
+    "DescribeConnectionsResponseTypeDef",
+    {"Marker": str, "Connections": List["ConnectionTypeDef"]},
+    total=False,
+)
+
+DescribeEndpointTypesResponseTypeDef = TypedDict(
+    "DescribeEndpointTypesResponseTypeDef",
+    {"Marker": str, "SupportedEndpointTypes": List["SupportedEndpointTypeTypeDef"]},
+    total=False,
+)
+
+DescribeEndpointsResponseTypeDef = TypedDict(
+    "DescribeEndpointsResponseTypeDef",
+    {"Marker": str, "Endpoints": List["EndpointTypeDef"]},
+    total=False,
+)
+
+DescribeEventCategoriesResponseTypeDef = TypedDict(
+    "DescribeEventCategoriesResponseTypeDef",
+    {"EventCategoryGroupList": List["EventCategoryGroupTypeDef"]},
+    total=False,
+)
+
+DescribeEventSubscriptionsResponseTypeDef = TypedDict(
+    "DescribeEventSubscriptionsResponseTypeDef",
+    {"Marker": str, "EventSubscriptionsList": List["EventSubscriptionTypeDef"]},
+    total=False,
+)
+
+DescribeEventsResponseTypeDef = TypedDict(
+    "DescribeEventsResponseTypeDef", {"Marker": str, "Events": List["EventTypeDef"]}, total=False
+)
+
+DescribeOrderableReplicationInstancesResponseTypeDef = TypedDict(
+    "DescribeOrderableReplicationInstancesResponseTypeDef",
+    {"OrderableReplicationInstances": List["OrderableReplicationInstanceTypeDef"], "Marker": str},
+    total=False,
+)
+
+DescribePendingMaintenanceActionsResponseTypeDef = TypedDict(
+    "DescribePendingMaintenanceActionsResponseTypeDef",
+    {"PendingMaintenanceActions": List["ResourcePendingMaintenanceActionsTypeDef"], "Marker": str},
+    total=False,
+)
+
+DescribeRefreshSchemasStatusResponseTypeDef = TypedDict(
+    "DescribeRefreshSchemasStatusResponseTypeDef",
+    {"RefreshSchemasStatus": "RefreshSchemasStatusTypeDef"},
+    total=False,
+)
+
+DescribeReplicationInstanceTaskLogsResponseTypeDef = TypedDict(
+    "DescribeReplicationInstanceTaskLogsResponseTypeDef",
+    {
+        "ReplicationInstanceArn": str,
+        "ReplicationInstanceTaskLogs": List["ReplicationInstanceTaskLogTypeDef"],
+        "Marker": str,
+    },
+    total=False,
+)
+
+DescribeReplicationInstancesResponseTypeDef = TypedDict(
+    "DescribeReplicationInstancesResponseTypeDef",
+    {"Marker": str, "ReplicationInstances": List["ReplicationInstanceTypeDef"]},
+    total=False,
+)
+
+DescribeReplicationSubnetGroupsResponseTypeDef = TypedDict(
+    "DescribeReplicationSubnetGroupsResponseTypeDef",
+    {"Marker": str, "ReplicationSubnetGroups": List["ReplicationSubnetGroupTypeDef"]},
+    total=False,
+)
+
+DescribeReplicationTaskAssessmentResultsResponseTypeDef = TypedDict(
+    "DescribeReplicationTaskAssessmentResultsResponseTypeDef",
+    {
+        "Marker": str,
+        "BucketName": str,
+        "ReplicationTaskAssessmentResults": List["ReplicationTaskAssessmentResultTypeDef"],
+    },
+    total=False,
+)
+
+DescribeReplicationTasksResponseTypeDef = TypedDict(
+    "DescribeReplicationTasksResponseTypeDef",
+    {"Marker": str, "ReplicationTasks": List["ReplicationTaskTypeDef"]},
+    total=False,
+)
+
+DescribeSchemasResponseTypeDef = TypedDict(
+    "DescribeSchemasResponseTypeDef", {"Marker": str, "Schemas": List[str]}, total=False
+)
+
 DescribeTableStatisticsResponseTypeDef = TypedDict(
     "DescribeTableStatisticsResponseTypeDef",
-    {"ReplicationTaskArn": str, "TableStatistics": List[TableStatisticsTypeDef], "Marker": str},
+    {"ReplicationTaskArn": str, "TableStatistics": List["TableStatisticsTypeDef"], "Marker": str},
     total=False,
 )
 
 FilterTypeDef = TypedDict("FilterTypeDef", {"Name": str, "Values": List[str]})
 
 ImportCertificateResponseTypeDef = TypedDict(
-    "ImportCertificateResponseTypeDef", {"Certificate": CertificateTypeDef}, total=False
+    "ImportCertificateResponseTypeDef", {"Certificate": "CertificateTypeDef"}, total=False
 )
 
-TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str}, total=False)
-
 ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef", {"TagList": List[TagTypeDef]}, total=False
+    "ListTagsForResourceResponseTypeDef", {"TagList": List["TagTypeDef"]}, total=False
 )
 
 ModifyEndpointResponseTypeDef = TypedDict(
-    "ModifyEndpointResponseTypeDef", {"Endpoint": EndpointTypeDef}, total=False
+    "ModifyEndpointResponseTypeDef", {"Endpoint": "EndpointTypeDef"}, total=False
 )
 
 ModifyEventSubscriptionResponseTypeDef = TypedDict(
     "ModifyEventSubscriptionResponseTypeDef",
-    {"EventSubscription": EventSubscriptionTypeDef},
+    {"EventSubscription": "EventSubscriptionTypeDef"},
     total=False,
 )
 
 ModifyReplicationInstanceResponseTypeDef = TypedDict(
     "ModifyReplicationInstanceResponseTypeDef",
-    {"ReplicationInstance": ReplicationInstanceTypeDef},
+    {"ReplicationInstance": "ReplicationInstanceTypeDef"},
     total=False,
 )
 
 ModifyReplicationSubnetGroupResponseTypeDef = TypedDict(
     "ModifyReplicationSubnetGroupResponseTypeDef",
-    {"ReplicationSubnetGroup": ReplicationSubnetGroupTypeDef},
+    {"ReplicationSubnetGroup": "ReplicationSubnetGroupTypeDef"},
     total=False,
 )
 
 ModifyReplicationTaskResponseTypeDef = TypedDict(
-    "ModifyReplicationTaskResponseTypeDef", {"ReplicationTask": ReplicationTaskTypeDef}, total=False
+    "ModifyReplicationTaskResponseTypeDef",
+    {"ReplicationTask": "ReplicationTaskTypeDef"},
+    total=False,
 )
 
 PaginatorConfigTypeDef = TypedDict(
@@ -778,13 +784,13 @@ PaginatorConfigTypeDef = TypedDict(
 
 RebootReplicationInstanceResponseTypeDef = TypedDict(
     "RebootReplicationInstanceResponseTypeDef",
-    {"ReplicationInstance": ReplicationInstanceTypeDef},
+    {"ReplicationInstance": "ReplicationInstanceTypeDef"},
     total=False,
 )
 
 RefreshSchemasResponseTypeDef = TypedDict(
     "RefreshSchemasResponseTypeDef",
-    {"RefreshSchemasStatus": RefreshSchemasStatusTypeDef},
+    {"RefreshSchemasStatus": "RefreshSchemasStatusTypeDef"},
     total=False,
 )
 
@@ -794,16 +800,18 @@ ReloadTablesResponseTypeDef = TypedDict(
 
 StartReplicationTaskAssessmentResponseTypeDef = TypedDict(
     "StartReplicationTaskAssessmentResponseTypeDef",
-    {"ReplicationTask": ReplicationTaskTypeDef},
+    {"ReplicationTask": "ReplicationTaskTypeDef"},
     total=False,
 )
 
 StartReplicationTaskResponseTypeDef = TypedDict(
-    "StartReplicationTaskResponseTypeDef", {"ReplicationTask": ReplicationTaskTypeDef}, total=False
+    "StartReplicationTaskResponseTypeDef",
+    {"ReplicationTask": "ReplicationTaskTypeDef"},
+    total=False,
 )
 
 StopReplicationTaskResponseTypeDef = TypedDict(
-    "StopReplicationTaskResponseTypeDef", {"ReplicationTask": ReplicationTaskTypeDef}, total=False
+    "StopReplicationTaskResponseTypeDef", {"ReplicationTask": "ReplicationTaskTypeDef"}, total=False
 )
 
 TableToReloadTypeDef = TypedDict(
@@ -811,7 +819,7 @@ TableToReloadTypeDef = TypedDict(
 )
 
 TestConnectionResponseTypeDef = TypedDict(
-    "TestConnectionResponseTypeDef", {"Connection": ConnectionTypeDef}, total=False
+    "TestConnectionResponseTypeDef", {"Connection": "ConnectionTypeDef"}, total=False
 )
 
 WaiterConfigTypeDef = TypedDict(
